# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1/proto/service.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2
from google.api import resource_pb2 as google_dot_api_dot_resource__pb2
from google.cloud.automl_v1.proto import (
    annotation_payload_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__payload__pb2,
)
from google.cloud.automl_v1.proto import (
    annotation_spec_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__spec__pb2,
)
from google.cloud.automl_v1.proto import (
    dataset_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2,
)
from google.cloud.automl_v1.proto import (
    image_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2,
)
from google.cloud.automl_v1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1.proto import (
    model_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2,
)
from google.cloud.automl_v1.proto import (
    model_evaluation_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_model__evaluation__pb2,
)
from google.cloud.automl_v1.proto import (
    operations_pb2 as google_dot_cloud_dot_automl__v1_dot_proto_dot_operations__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)
from google.protobuf import field_mask_pb2 as google_dot_protobuf_dot_field__mask__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1/proto/service.proto",
    package="google.cloud.automl.v1",
    syntax="proto3",
    serialized_options=_b(
        "\n\032com.google.cloud.automl.v1B\013AutoMlProtoP\001Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\252\002\026Google.Cloud.AutoML.V1\312\002\026Google\\Cloud\\AutoMl\\V1\352\002\031Google::Cloud::AutoML::V1"
    ),
    serialized_pb=_b(
        '\n*google/cloud/automl_v1/proto/service.proto\x12\x16google.cloud.automl.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\x1a\x19google/api/resource.proto\x1a\x35google/cloud/automl_v1/proto/annotation_payload.proto\x1a\x32google/cloud/automl_v1/proto/annotation_spec.proto\x1a*google/cloud/automl_v1/proto/dataset.proto\x1a(google/cloud/automl_v1/proto/image.proto\x1a%google/cloud/automl_v1/proto/io.proto\x1a(google/cloud/automl_v1/proto/model.proto\x1a\x33google/cloud/automl_v1/proto/model_evaluation.proto\x1a-google/cloud/automl_v1/proto/operations.proto\x1a#google/longrunning/operations.proto\x1a google/protobuf/field_mask.proto"X\n\x14\x43reateDatasetRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x30\n\x07\x64\x61taset\x18\x02 \x01(\x0b\x32\x1f.google.cloud.automl.v1.Dataset"!\n\x11GetDatasetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\\\n\x13ListDatasetsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"b\n\x14ListDatasetsResponse\x12\x31\n\x08\x64\x61tasets\x18\x01 \x03(\x0b\x32\x1f.google.cloud.automl.v1.Dataset\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t"y\n\x14UpdateDatasetRequest\x12\x30\n\x07\x64\x61taset\x18\x01 \x01(\x0b\x32\x1f.google.cloud.automl.v1.Dataset\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"$\n\x14\x44\x65leteDatasetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"\\\n\x11ImportDataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x39\n\x0cinput_config\x18\x03 \x01(\x0b\x32#.google.cloud.automl.v1.InputConfig"^\n\x11\x45xportDataRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12;\n\routput_config\x18\x03 \x01(\x0b\x32$.google.cloud.automl.v1.OutputConfig"(\n\x18GetAnnotationSpecRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"R\n\x12\x43reateModelRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12,\n\x05model\x18\x04 \x01(\x0b\x32\x1d.google.cloud.automl.v1.Model"\x1f\n\x0fGetModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"Z\n\x11ListModelsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"[\n\x12ListModelsResponse\x12,\n\x05model\x18\x01 \x03(\x0b\x32\x1d.google.cloud.automl.v1.Model\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t""\n\x12\x44\x65leteModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"s\n\x12UpdateModelRequest\x12,\n\x05model\x18\x01 \x01(\x0b\x32\x1d.google.cloud.automl.v1.Model\x12/\n\x0bupdate_mask\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.FieldMask"\xbe\x02\n\x12\x44\x65ployModelRequest\x12\x7f\n0image_object_detection_model_deployment_metadata\x18\x02 \x01(\x0b\x32\x43.google.cloud.automl.v1.ImageObjectDetectionModelDeploymentMetadataH\x00\x12|\n.image_classification_model_deployment_metadata\x18\x04 \x01(\x0b\x32\x42.google.cloud.automl.v1.ImageClassificationModelDeploymentMetadataH\x00\x12\x0c\n\x04name\x18\x01 \x01(\tB\x1b\n\x19model_deployment_metadata"$\n\x14UndeployModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"j\n\x12\x45xportModelRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x46\n\routput_config\x18\x03 \x01(\x0b\x32/.google.cloud.automl.v1.ModelExportOutputConfig")\n\x19GetModelEvaluationRequest\x12\x0c\n\x04name\x18\x01 \x01(\t"d\n\x1bListModelEvaluationsRequest\x12\x0e\n\x06parent\x18\x01 \x01(\t\x12\x0e\n\x06\x66ilter\x18\x03 \x01(\t\x12\x11\n\tpage_size\x18\x04 \x01(\x05\x12\x12\n\npage_token\x18\x06 \x01(\t"z\n\x1cListModelEvaluationsResponse\x12\x41\n\x10model_evaluation\x18\x01 \x03(\x0b\x32\'.google.cloud.automl.v1.ModelEvaluation\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t2\x8d\x17\n\x06\x41utoMl\x12\x9b\x01\n\rCreateDataset\x12,.google.cloud.automl.v1.CreateDatasetRequest\x1a\x1d.google.longrunning.Operation"=\x82\xd3\xe4\x93\x02\x37",/v1/{parent=projects/*/locations/*}/datasets:\x07\x64\x61taset\x12\x8e\x01\n\nGetDataset\x12).google.cloud.automl.v1.GetDatasetRequest\x1a\x1f.google.cloud.automl.v1.Dataset"4\x82\xd3\xe4\x93\x02.\x12,/v1/{name=projects/*/locations/*/datasets/*}\x12\x9f\x01\n\x0cListDatasets\x12+.google.cloud.automl.v1.ListDatasetsRequest\x1a,.google.cloud.automl.v1.ListDatasetsResponse"4\x82\xd3\xe4\x93\x02.\x12,/v1/{parent=projects/*/locations/*}/datasets\x12\xa5\x01\n\rUpdateDataset\x12,.google.cloud.automl.v1.UpdateDatasetRequest\x1a\x1f.google.cloud.automl.v1.Dataset"E\x82\xd3\xe4\x93\x02?24/v1/{dataset.name=projects/*/locations/*/datasets/*}:\x07\x64\x61taset\x12\x92\x01\n\rDeleteDataset\x12,.google.cloud.automl.v1.DeleteDatasetRequest\x1a\x1d.google.longrunning.Operation"4\x82\xd3\xe4\x93\x02.*,/v1/{name=projects/*/locations/*/datasets/*}\x12\x9a\x01\n\nImportData\x12).google.cloud.automl.v1.ImportDataRequest\x1a\x1d.google.longrunning.Operation"B\x82\xd3\xe4\x93\x02<"7/v1/{name=projects/*/locations/*/datasets/*}:importData:\x01*\x12\x9a\x01\n\nExportData\x12).google.cloud.automl.v1.ExportDataRequest\x1a\x1d.google.longrunning.Operation"B\x82\xd3\xe4\x93\x02<"7/v1/{name=projects/*/locations/*/datasets/*}:exportData:\x01*\x12\xb5\x01\n\x11GetAnnotationSpec\x12\x30.google.cloud.automl.v1.GetAnnotationSpecRequest\x1a&.google.cloud.automl.v1.AnnotationSpec"F\x82\xd3\xe4\x93\x02@\x12>/v1/{name=projects/*/locations/*/datasets/*/annotationSpecs/*}\x12\x93\x01\n\x0b\x43reateModel\x12*.google.cloud.automl.v1.CreateModelRequest\x1a\x1d.google.longrunning.Operation"9\x82\xd3\xe4\x93\x02\x33"*/v1/{parent=projects/*/locations/*}/models:\x05model\x12\x86\x01\n\x08GetModel\x12\'.google.cloud.automl.v1.GetModelRequest\x1a\x1d.google.cloud.automl.v1.Model"2\x82\xd3\xe4\x93\x02,\x12*/v1/{name=projects/*/locations/*/models/*}\x12\x97\x01\n\nListModels\x12).google.cloud.automl.v1.ListModelsRequest\x1a*.google.cloud.automl.v1.ListModelsResponse"2\x82\xd3\xe4\x93\x02,\x12*/v1/{parent=projects/*/locations/*}/models\x12\x8c\x01\n\x0b\x44\x65leteModel\x12*.google.cloud.automl.v1.DeleteModelRequest\x1a\x1d.google.longrunning.Operation"2\x82\xd3\xe4\x93\x02,**/v1/{name=projects/*/locations/*/models/*}\x12\x99\x01\n\x0bUpdateModel\x12*.google.cloud.automl.v1.UpdateModelRequest\x1a\x1d.google.cloud.automl.v1.Model"?\x82\xd3\xe4\x93\x02\x39\x32\x30/v1/{model.name=projects/*/locations/*/models/*}:\x05model\x12\x96\x01\n\x0b\x44\x65ployModel\x12*.google.cloud.automl.v1.DeployModelRequest\x1a\x1d.google.longrunning.Operation"<\x82\xd3\xe4\x93\x02\x36"1/v1/{name=projects/*/locations/*/models/*}:deploy:\x01*\x12\x9c\x01\n\rUndeployModel\x12,.google.cloud.automl.v1.UndeployModelRequest\x1a\x1d.google.longrunning.Operation">\x82\xd3\xe4\x93\x02\x38"3/v1/{name=projects/*/locations/*/models/*}:undeploy:\x01*\x12\x96\x01\n\x0b\x45xportModel\x12*.google.cloud.automl.v1.ExportModelRequest\x1a\x1d.google.longrunning.Operation"<\x82\xd3\xe4\x93\x02\x36"1/v1/{name=projects/*/locations/*/models/*}:export:\x01*\x12\xb7\x01\n\x12GetModelEvaluation\x12\x31.google.cloud.automl.v1.GetModelEvaluationRequest\x1a\'.google.cloud.automl.v1.ModelEvaluation"E\x82\xd3\xe4\x93\x02?\x12=/v1/{name=projects/*/locations/*/models/*/modelEvaluations/*}\x12\xc8\x01\n\x14ListModelEvaluations\x12\x33.google.cloud.automl.v1.ListModelEvaluationsRequest\x1a\x34.google.cloud.automl.v1.ListModelEvaluationsResponse"E\x82\xd3\xe4\x93\x02?\x12=/v1/{parent=projects/*/locations/*/models/*}/modelEvaluations\x1aI\xca\x41\x15\x61utoml.googleapis.com\xd2\x41.https://www.googleapis.com/auth/cloud-platformB\xb7\x01\n\x1a\x63om.google.cloud.automl.v1B\x0b\x41utoMlProtoP\x01Z<google.golang.org/genproto/googleapis/cloud/automl/v1;automl\xaa\x02\x16Google.Cloud.AutoML.V1\xca\x02\x16Google\\Cloud\\AutoMl\\V1\xea\x02\x19Google::Cloud::AutoML::V1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_api_dot_client__pb2.DESCRIPTOR,
        google_dot_api_dot_resource__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__payload__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__spec__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_model__evaluation__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1_dot_proto_dot_operations__pb2.DESCRIPTOR,
        google_dot_longrunning_dot_operations__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_field__mask__pb2.DESCRIPTOR,
    ],
)


_CREATEDATASETREQUEST = _descriptor.Descriptor(
    name="CreateDatasetRequest",
    full_name="google.cloud.automl.v1.CreateDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1.CreateDatasetRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="google.cloud.automl.v1.CreateDatasetRequest.dataset",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=597,
    serialized_end=685,
)


_GETDATASETREQUEST = _descriptor.Descriptor(
    name="GetDatasetRequest",
    full_name="google.cloud.automl.v1.GetDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.GetDatasetRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=687,
    serialized_end=720,
)


_LISTDATASETSREQUEST = _descriptor.Descriptor(
    name="ListDatasetsRequest",
    full_name="google.cloud.automl.v1.ListDatasetsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1.ListDatasetsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1.ListDatasetsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1.ListDatasetsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1.ListDatasetsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=722,
    serialized_end=814,
)


_LISTDATASETSRESPONSE = _descriptor.Descriptor(
    name="ListDatasetsResponse",
    full_name="google.cloud.automl.v1.ListDatasetsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="datasets",
            full_name="google.cloud.automl.v1.ListDatasetsResponse.datasets",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1.ListDatasetsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=816,
    serialized_end=914,
)


_UPDATEDATASETREQUEST = _descriptor.Descriptor(
    name="UpdateDatasetRequest",
    full_name="google.cloud.automl.v1.UpdateDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="dataset",
            full_name="google.cloud.automl.v1.UpdateDatasetRequest.dataset",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.automl.v1.UpdateDatasetRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=916,
    serialized_end=1037,
)


_DELETEDATASETREQUEST = _descriptor.Descriptor(
    name="DeleteDatasetRequest",
    full_name="google.cloud.automl.v1.DeleteDatasetRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.DeleteDatasetRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1039,
    serialized_end=1075,
)


_IMPORTDATAREQUEST = _descriptor.Descriptor(
    name="ImportDataRequest",
    full_name="google.cloud.automl.v1.ImportDataRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.ImportDataRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1.ImportDataRequest.input_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1077,
    serialized_end=1169,
)


_EXPORTDATAREQUEST = _descriptor.Descriptor(
    name="ExportDataRequest",
    full_name="google.cloud.automl.v1.ExportDataRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.ExportDataRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1.ExportDataRequest.output_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1171,
    serialized_end=1265,
)


_GETANNOTATIONSPECREQUEST = _descriptor.Descriptor(
    name="GetAnnotationSpecRequest",
    full_name="google.cloud.automl.v1.GetAnnotationSpecRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.GetAnnotationSpecRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1267,
    serialized_end=1307,
)


_CREATEMODELREQUEST = _descriptor.Descriptor(
    name="CreateModelRequest",
    full_name="google.cloud.automl.v1.CreateModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1.CreateModelRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.automl.v1.CreateModelRequest.model",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1309,
    serialized_end=1391,
)


_GETMODELREQUEST = _descriptor.Descriptor(
    name="GetModelRequest",
    full_name="google.cloud.automl.v1.GetModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.GetModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1393,
    serialized_end=1424,
)


_LISTMODELSREQUEST = _descriptor.Descriptor(
    name="ListModelsRequest",
    full_name="google.cloud.automl.v1.ListModelsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1.ListModelsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1.ListModelsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1.ListModelsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1.ListModelsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1426,
    serialized_end=1516,
)


_LISTMODELSRESPONSE = _descriptor.Descriptor(
    name="ListModelsResponse",
    full_name="google.cloud.automl.v1.ListModelsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.automl.v1.ListModelsResponse.model",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1.ListModelsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1518,
    serialized_end=1609,
)


_DELETEMODELREQUEST = _descriptor.Descriptor(
    name="DeleteModelRequest",
    full_name="google.cloud.automl.v1.DeleteModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.DeleteModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1611,
    serialized_end=1645,
)


_UPDATEMODELREQUEST = _descriptor.Descriptor(
    name="UpdateModelRequest",
    full_name="google.cloud.automl.v1.UpdateModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model",
            full_name="google.cloud.automl.v1.UpdateModelRequest.model",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="update_mask",
            full_name="google.cloud.automl.v1.UpdateModelRequest.update_mask",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=1647,
    serialized_end=1762,
)


_DEPLOYMODELREQUEST = _descriptor.Descriptor(
    name="DeployModelRequest",
    full_name="google.cloud.automl.v1.DeployModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image_object_detection_model_deployment_metadata",
            full_name="google.cloud.automl.v1.DeployModelRequest.image_object_detection_model_deployment_metadata",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="image_classification_model_deployment_metadata",
            full_name="google.cloud.automl.v1.DeployModelRequest.image_classification_model_deployment_metadata",
            index=1,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.DeployModelRequest.name",
            index=2,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="model_deployment_metadata",
            full_name="google.cloud.automl.v1.DeployModelRequest.model_deployment_metadata",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=1765,
    serialized_end=2083,
)


_UNDEPLOYMODELREQUEST = _descriptor.Descriptor(
    name="UndeployModelRequest",
    full_name="google.cloud.automl.v1.UndeployModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.UndeployModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2085,
    serialized_end=2121,
)


_EXPORTMODELREQUEST = _descriptor.Descriptor(
    name="ExportModelRequest",
    full_name="google.cloud.automl.v1.ExportModelRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.ExportModelRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="output_config",
            full_name="google.cloud.automl.v1.ExportModelRequest.output_config",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2123,
    serialized_end=2229,
)


_GETMODELEVALUATIONREQUEST = _descriptor.Descriptor(
    name="GetModelEvaluationRequest",
    full_name="google.cloud.automl.v1.GetModelEvaluationRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="name",
            full_name="google.cloud.automl.v1.GetModelEvaluationRequest.name",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2231,
    serialized_end=2272,
)


_LISTMODELEVALUATIONSREQUEST = _descriptor.Descriptor(
    name="ListModelEvaluationsRequest",
    full_name="google.cloud.automl.v1.ListModelEvaluationsRequest",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="parent",
            full_name="google.cloud.automl.v1.ListModelEvaluationsRequest.parent",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="filter",
            full_name="google.cloud.automl.v1.ListModelEvaluationsRequest.filter",
            index=1,
            number=3,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_size",
            full_name="google.cloud.automl.v1.ListModelEvaluationsRequest.page_size",
            index=2,
            number=4,
            type=5,
            cpp_type=1,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="page_token",
            full_name="google.cloud.automl.v1.ListModelEvaluationsRequest.page_token",
            index=3,
            number=6,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2274,
    serialized_end=2374,
)


_LISTMODELEVALUATIONSRESPONSE = _descriptor.Descriptor(
    name="ListModelEvaluationsResponse",
    full_name="google.cloud.automl.v1.ListModelEvaluationsResponse",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="model_evaluation",
            full_name="google.cloud.automl.v1.ListModelEvaluationsResponse.model_evaluation",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="next_page_token",
            full_name="google.cloud.automl.v1.ListModelEvaluationsResponse.next_page_token",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=2376,
    serialized_end=2498,
)

_CREATEDATASETREQUEST.fields_by_name[
    "dataset"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2._DATASET
_LISTDATASETSRESPONSE.fields_by_name[
    "datasets"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2._DATASET
_UPDATEDATASETREQUEST.fields_by_name[
    "dataset"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2._DATASET
_UPDATEDATASETREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_IMPORTDATAREQUEST.fields_by_name[
    "input_config"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2._INPUTCONFIG
_EXPORTDATAREQUEST.fields_by_name[
    "output_config"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2._OUTPUTCONFIG
_CREATEMODELREQUEST.fields_by_name[
    "model"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2._MODEL
_LISTMODELSRESPONSE.fields_by_name[
    "model"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2._MODEL
_UPDATEMODELREQUEST.fields_by_name[
    "model"
].message_type = google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2._MODEL
_UPDATEMODELREQUEST.fields_by_name[
    "update_mask"
].message_type = google_dot_protobuf_dot_field__mask__pb2._FIELDMASK
_DEPLOYMODELREQUEST.fields_by_name[
    "image_object_detection_model_deployment_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGEOBJECTDETECTIONMODELDEPLOYMENTMETADATA
)
_DEPLOYMODELREQUEST.fields_by_name[
    "image_classification_model_deployment_metadata"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_image__pb2._IMAGECLASSIFICATIONMODELDEPLOYMENTMETADATA
)
_DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"].fields.append(
    _DEPLOYMODELREQUEST.fields_by_name[
        "image_object_detection_model_deployment_metadata"
    ]
)
_DEPLOYMODELREQUEST.fields_by_name[
    "image_object_detection_model_deployment_metadata"
].containing_oneof = _DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"]
_DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"].fields.append(
    _DEPLOYMODELREQUEST.fields_by_name["image_classification_model_deployment_metadata"]
)
_DEPLOYMODELREQUEST.fields_by_name[
    "image_classification_model_deployment_metadata"
].containing_oneof = _DEPLOYMODELREQUEST.oneofs_by_name["model_deployment_metadata"]
_EXPORTMODELREQUEST.fields_by_name[
    "output_config"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_io__pb2._MODELEXPORTOUTPUTCONFIG
)
_LISTMODELEVALUATIONSRESPONSE.fields_by_name[
    "model_evaluation"
].message_type = (
    google_dot_cloud_dot_automl__v1_dot_proto_dot_model__evaluation__pb2._MODELEVALUATION
)
DESCRIPTOR.message_types_by_name["CreateDatasetRequest"] = _CREATEDATASETREQUEST
DESCRIPTOR.message_types_by_name["GetDatasetRequest"] = _GETDATASETREQUEST
DESCRIPTOR.message_types_by_name["ListDatasetsRequest"] = _LISTDATASETSREQUEST
DESCRIPTOR.message_types_by_name["ListDatasetsResponse"] = _LISTDATASETSRESPONSE
DESCRIPTOR.message_types_by_name["UpdateDatasetRequest"] = _UPDATEDATASETREQUEST
DESCRIPTOR.message_types_by_name["DeleteDatasetRequest"] = _DELETEDATASETREQUEST
DESCRIPTOR.message_types_by_name["ImportDataRequest"] = _IMPORTDATAREQUEST
DESCRIPTOR.message_types_by_name["ExportDataRequest"] = _EXPORTDATAREQUEST
DESCRIPTOR.message_types_by_name["GetAnnotationSpecRequest"] = _GETANNOTATIONSPECREQUEST
DESCRIPTOR.message_types_by_name["CreateModelRequest"] = _CREATEMODELREQUEST
DESCRIPTOR.message_types_by_name["GetModelRequest"] = _GETMODELREQUEST
DESCRIPTOR.message_types_by_name["ListModelsRequest"] = _LISTMODELSREQUEST
DESCRIPTOR.message_types_by_name["ListModelsResponse"] = _LISTMODELSRESPONSE
DESCRIPTOR.message_types_by_name["DeleteModelRequest"] = _DELETEMODELREQUEST
DESCRIPTOR.message_types_by_name["UpdateModelRequest"] = _UPDATEMODELREQUEST
DESCRIPTOR.message_types_by_name["DeployModelRequest"] = _DEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name["UndeployModelRequest"] = _UNDEPLOYMODELREQUEST
DESCRIPTOR.message_types_by_name["ExportModelRequest"] = _EXPORTMODELREQUEST
DESCRIPTOR.message_types_by_name[
    "GetModelEvaluationRequest"
] = _GETMODELEVALUATIONREQUEST
DESCRIPTOR.message_types_by_name[
    "ListModelEvaluationsRequest"
] = _LISTMODELEVALUATIONSREQUEST
DESCRIPTOR.message_types_by_name[
    "ListModelEvaluationsResponse"
] = _LISTMODELEVALUATIONSRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "CreateDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEDATASETREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.CreateDataset][google.cloud.automl.v1.AutoMl.CreateDataset].
  
  
  Attributes:
      parent:
          The resource name of the project to create the dataset for.
      dataset:
          The dataset to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.CreateDatasetRequest)
    ),
)
_sym_db.RegisterMessage(CreateDatasetRequest)

GetDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "GetDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETDATASETREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetDataset][google.cloud.automl.v1.AutoMl.GetDataset].
  
  
  Attributes:
      name:
          The resource name of the dataset to retrieve.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GetDatasetRequest)
    ),
)
_sym_db.RegisterMessage(GetDatasetRequest)

ListDatasetsRequest = _reflection.GeneratedProtocolMessageType(
    "ListDatasetsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASETSREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
  
  
  Attributes:
      parent:
          The resource name of the project from which to list datasets.
      filter:
          An expression for filtering the results of the request.  -
          ``dataset_metadata`` - for existence of the case (e.g.
          image\_classification\_dataset\_metadata:\*). Some examples of
          using    the filter are:  -
          ``translation_dataset_metadata:*`` --> The dataset has
          translation\_dataset\_metadata.
      page_size:
          Requested page size. Server may return fewer results than
          requested. If unspecified, server will pick a default size.
      page_token:
          A token identifying a page of results for the server to return
          Typically obtained via [ListDatasetsResponse.next\_page\_token
          ][google.cloud.automl.v1.ListDatasetsResponse.next\_page\_toke
          n] of the previous [AutoMl.ListDatasets][google.cloud.automl.v
          1.AutoMl.ListDatasets] call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListDatasetsRequest)
    ),
)
_sym_db.RegisterMessage(ListDatasetsRequest)

ListDatasetsResponse = _reflection.GeneratedProtocolMessageType(
    "ListDatasetsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTDATASETSRESPONSE,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListDatasets][google.cloud.automl.v1.AutoMl.ListDatasets].
  
  
  Attributes:
      datasets:
          The datasets read.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListDataset
          sRequest.page\_token][google.cloud.automl.v1.ListDatasetsReque
          st.page\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListDatasetsResponse)
    ),
)
_sym_db.RegisterMessage(ListDatasetsResponse)

UpdateDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEDATASETREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UpdateDataset][google.cloud.automl.v1.AutoMl.UpdateDataset]
  
  
  Attributes:
      dataset:
          The dataset which replaces the resource on the server.
      update_mask:
          Required. The update mask applies to the resource.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.UpdateDatasetRequest)
    ),
)
_sym_db.RegisterMessage(UpdateDatasetRequest)

DeleteDatasetRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteDatasetRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEDATASETREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeleteDataset][google.cloud.automl.v1.AutoMl.DeleteDataset].
  
  
  Attributes:
      name:
          The resource name of the dataset to delete.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.DeleteDatasetRequest)
    ),
)
_sym_db.RegisterMessage(DeleteDatasetRequest)

ImportDataRequest = _reflection.GeneratedProtocolMessageType(
    "ImportDataRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMPORTDATAREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ImportData][google.cloud.automl.v1.AutoMl.ImportData].
  
  
  Attributes:
      name:
          Required. Dataset name. Dataset must already exist. All
          imported annotations and examples will be added.
      input_config:
          Required. The desired input location and its domain specific
          semantics, if any.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ImportDataRequest)
    ),
)
_sym_db.RegisterMessage(ImportDataRequest)

ExportDataRequest = _reflection.GeneratedProtocolMessageType(
    "ExportDataRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTDATAREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ExportData][google.cloud.automl.v1.AutoMl.ExportData].
  
  
  Attributes:
      name:
          Required. The resource name of the dataset.
      output_config:
          Required. The desired output location.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ExportDataRequest)
    ),
)
_sym_db.RegisterMessage(ExportDataRequest)

GetAnnotationSpecRequest = _reflection.GeneratedProtocolMessageType(
    "GetAnnotationSpecRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETANNOTATIONSPECREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetAnnotationSpec][google.cloud.automl.v1.AutoMl.GetAnnotationSpec].
  
  
  Attributes:
      name:
          The resource name of the annotation spec to retrieve.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GetAnnotationSpecRequest)
    ),
)
_sym_db.RegisterMessage(GetAnnotationSpecRequest)

CreateModelRequest = _reflection.GeneratedProtocolMessageType(
    "CreateModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_CREATEMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.CreateModel][google.cloud.automl.v1.AutoMl.CreateModel].
  
  
  Attributes:
      parent:
          Resource name of the parent project where the model is being
          created.
      model:
          The model to create.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.CreateModelRequest)
    ),
)
_sym_db.RegisterMessage(CreateModelRequest)

GetModelRequest = _reflection.GeneratedProtocolMessageType(
    "GetModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetModel][google.cloud.automl.v1.AutoMl.GetModel].
  
  
  Attributes:
      name:
          Resource name of the model.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GetModelRequest)
    ),
)
_sym_db.RegisterMessage(GetModelRequest)

ListModelsRequest = _reflection.GeneratedProtocolMessageType(
    "ListModelsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELSREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
  
  
  Attributes:
      parent:
          Resource name of the project, from which to list the models.
      filter:
          An expression for filtering the results of the request.  -
          ``model_metadata`` - for existence of the case (e.g.
          image\_classification\_model\_metadata:\*). -  ``dataset_id``
          - for = or !=. Some examples of using the filter are:  -
          ``image_classification_model_metadata:*`` --> The model has
          image\_classification\_model\_metadata. -  ``dataset_id=5``
          --> The model was created from a dataset with ID 5.
      page_size:
          Requested page size.
      page_token:
          A token identifying a page of results for the server to return
          Typically obtained via [ListModelsResponse.next\_page\_token][
          google.cloud.automl.v1.ListModelsResponse.next\_page\_token]
          of the previous
          [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels]
          call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListModelsRequest)
    ),
)
_sym_db.RegisterMessage(ListModelsRequest)

ListModelsResponse = _reflection.GeneratedProtocolMessageType(
    "ListModelsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELSRESPONSE,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListModels][google.cloud.automl.v1.AutoMl.ListModels].
  
  
  Attributes:
      model:
          List of models in the requested page.
      next_page_token:
          A token to retrieve next page of results. Pass to [ListModelsR
          equest.page\_token][google.cloud.automl.v1.ListModelsRequest.p
          age\_token] to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListModelsResponse)
    ),
)
_sym_db.RegisterMessage(ListModelsResponse)

DeleteModelRequest = _reflection.GeneratedProtocolMessageType(
    "DeleteModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DELETEMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeleteModel][google.cloud.automl.v1.AutoMl.DeleteModel].
  
  
  Attributes:
      name:
          Resource name of the model being deleted.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.DeleteModelRequest)
    ),
)
_sym_db.RegisterMessage(DeleteModelRequest)

UpdateModelRequest = _reflection.GeneratedProtocolMessageType(
    "UpdateModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UPDATEMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UpdateModel][google.cloud.automl.v1.AutoMl.UpdateModel]
  
  
  Attributes:
      model:
          The model which replaces the resource on the server.
      update_mask:
          Required. The update mask applies to the resource.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.UpdateModelRequest)
    ),
)
_sym_db.RegisterMessage(UpdateModelRequest)

DeployModelRequest = _reflection.GeneratedProtocolMessageType(
    "DeployModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DEPLOYMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.DeployModel][google.cloud.automl.v1.AutoMl.DeployModel].
  
  
  Attributes:
      model_deployment_metadata:
          The per-domain specific deployment parameters.
      image_object_detection_model_deployment_metadata:
          Model deployment metadata specific to Image Object Detection.
      image_classification_model_deployment_metadata:
          Model deployment metadata specific to Image Classification.
      name:
          Resource name of the model to deploy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.DeployModelRequest)
    ),
)
_sym_db.RegisterMessage(DeployModelRequest)

UndeployModelRequest = _reflection.GeneratedProtocolMessageType(
    "UndeployModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_UNDEPLOYMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.UndeployModel][google.cloud.automl.v1.AutoMl.UndeployModel].
  
  
  Attributes:
      name:
          Resource name of the model to undeploy.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.UndeployModelRequest)
    ),
)
_sym_db.RegisterMessage(UndeployModelRequest)

ExportModelRequest = _reflection.GeneratedProtocolMessageType(
    "ExportModelRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXPORTMODELREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ExportModel][google.cloud.automl.v1.AutoMl.ExportModel]. Models
  need to be enabled for exporting, otherwise an error code will be
  returned.
  
  
  Attributes:
      name:
          Required. The resource name of the model to export.
      output_config:
          Required. The desired output location and configuration.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ExportModelRequest)
    ),
)
_sym_db.RegisterMessage(ExportModelRequest)

GetModelEvaluationRequest = _reflection.GeneratedProtocolMessageType(
    "GetModelEvaluationRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_GETMODELEVALUATIONREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.GetModelEvaluation][google.cloud.automl.v1.AutoMl.GetModelEvaluation].
  
  
  Attributes:
      name:
          Resource name for the model evaluation.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.GetModelEvaluationRequest)
    ),
)
_sym_db.RegisterMessage(GetModelEvaluationRequest)

ListModelEvaluationsRequest = _reflection.GeneratedProtocolMessageType(
    "ListModelEvaluationsRequest",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELEVALUATIONSREQUEST,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Request message for
  [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
  
  
  Attributes:
      parent:
          Resource name of the model to list the model evaluations for.
          If modelId is set as "-", this will list model evaluations
          from across all models of the parent location.
      filter:
          An expression for filtering the results of the request.  -
          ``annotation_spec_id`` - for =, != or existence. See example
          below    for the last.  Some examples of using the filter are:
          -  ``annotation_spec_id!=4`` --> The model evaluation was done
          for    annotation spec with ID different than 4. -  ``NOT
          annotation_spec_id:*`` --> The model evaluation was done for
          aggregate of all annotation specs.
      page_size:
          Requested page size.
      page_token:
          A token identifying a page of results for the server to
          return. Typically obtained via [ListModelEvaluationsResponse.n
          ext\_page\_token][google.cloud.automl.v1.ListModelEvaluationsR
          esponse.next\_page\_token] of the previous [AutoMl.ListModelEv
          aluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations]
          call.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListModelEvaluationsRequest)
    ),
)
_sym_db.RegisterMessage(ListModelEvaluationsRequest)

ListModelEvaluationsResponse = _reflection.GeneratedProtocolMessageType(
    "ListModelEvaluationsResponse",
    (_message.Message,),
    dict(
        DESCRIPTOR=_LISTMODELEVALUATIONSRESPONSE,
        __module__="google.cloud.automl_v1.proto.service_pb2",
        __doc__="""Response message for
  [AutoMl.ListModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEvaluations].
  
  
  Attributes:
      model_evaluation:
          List of model evaluations in the requested page.
      next_page_token:
          A token to retrieve next page of results. Pass to the [ListMod
          elEvaluationsRequest.page\_token][google.cloud.automl.v1.ListM
          odelEvaluationsRequest.page\_token] field of a new [AutoMl.Lis
          tModelEvaluations][google.cloud.automl.v1.AutoMl.ListModelEval
          uations] request to obtain that page.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1.ListModelEvaluationsResponse)
    ),
)
_sym_db.RegisterMessage(ListModelEvaluationsResponse)


DESCRIPTOR._options = None

_AUTOML = _descriptor.ServiceDescriptor(
    name="AutoMl",
    full_name="google.cloud.automl.v1.AutoMl",
    file=DESCRIPTOR,
    index=0,
    serialized_options=_b(
        "\312A\025automl.googleapis.com\322A.https://www.googleapis.com/auth/cloud-platform"
    ),
    serialized_start=2501,
    serialized_end=5458,
    methods=[
        _descriptor.MethodDescriptor(
            name="CreateDataset",
            full_name="google.cloud.automl.v1.AutoMl.CreateDataset",
            index=0,
            containing_service=None,
            input_type=_CREATEDATASETREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0027",/v1/{parent=projects/*/locations/*}/datasets:\007dataset'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetDataset",
            full_name="google.cloud.automl.v1.AutoMl.GetDataset",
            index=1,
            containing_service=None,
            input_type=_GETDATASETREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2._DATASET,
            serialized_options=_b(
                "\202\323\344\223\002.\022,/v1/{name=projects/*/locations/*/datasets/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListDatasets",
            full_name="google.cloud.automl.v1.AutoMl.ListDatasets",
            index=2,
            containing_service=None,
            input_type=_LISTDATASETSREQUEST,
            output_type=_LISTDATASETSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002.\022,/v1/{parent=projects/*/locations/*}/datasets"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateDataset",
            full_name="google.cloud.automl.v1.AutoMl.UpdateDataset",
            index=3,
            containing_service=None,
            input_type=_UPDATEDATASETREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_dataset__pb2._DATASET,
            serialized_options=_b(
                "\202\323\344\223\002?24/v1/{dataset.name=projects/*/locations/*/datasets/*}:\007dataset"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteDataset",
            full_name="google.cloud.automl.v1.AutoMl.DeleteDataset",
            index=4,
            containing_service=None,
            input_type=_DELETEDATASETREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                "\202\323\344\223\002.*,/v1/{name=projects/*/locations/*/datasets/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ImportData",
            full_name="google.cloud.automl.v1.AutoMl.ImportData",
            index=5,
            containing_service=None,
            input_type=_IMPORTDATAREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002<"7/v1/{name=projects/*/locations/*/datasets/*}:importData:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ExportData",
            full_name="google.cloud.automl.v1.AutoMl.ExportData",
            index=6,
            containing_service=None,
            input_type=_EXPORTDATAREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\002<"7/v1/{name=projects/*/locations/*/datasets/*}:exportData:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetAnnotationSpec",
            full_name="google.cloud.automl.v1.AutoMl.GetAnnotationSpec",
            index=7,
            containing_service=None,
            input_type=_GETANNOTATIONSPECREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_annotation__spec__pb2._ANNOTATIONSPEC,
            serialized_options=_b(
                "\202\323\344\223\002@\022>/v1/{name=projects/*/locations/*/datasets/*/annotationSpecs/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="CreateModel",
            full_name="google.cloud.automl.v1.AutoMl.CreateModel",
            index=8,
            containing_service=None,
            input_type=_CREATEMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0023"*/v1/{parent=projects/*/locations/*}/models:\005model'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetModel",
            full_name="google.cloud.automl.v1.AutoMl.GetModel",
            index=9,
            containing_service=None,
            input_type=_GETMODELREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2._MODEL,
            serialized_options=_b(
                "\202\323\344\223\002,\022*/v1/{name=projects/*/locations/*/models/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListModels",
            full_name="google.cloud.automl.v1.AutoMl.ListModels",
            index=10,
            containing_service=None,
            input_type=_LISTMODELSREQUEST,
            output_type=_LISTMODELSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002,\022*/v1/{parent=projects/*/locations/*}/models"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeleteModel",
            full_name="google.cloud.automl.v1.AutoMl.DeleteModel",
            index=11,
            containing_service=None,
            input_type=_DELETEMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                "\202\323\344\223\002,**/v1/{name=projects/*/locations/*/models/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UpdateModel",
            full_name="google.cloud.automl.v1.AutoMl.UpdateModel",
            index=12,
            containing_service=None,
            input_type=_UPDATEMODELREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_model__pb2._MODEL,
            serialized_options=_b(
                "\202\323\344\223\002920/v1/{model.name=projects/*/locations/*/models/*}:\005model"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="DeployModel",
            full_name="google.cloud.automl.v1.AutoMl.DeployModel",
            index=13,
            containing_service=None,
            input_type=_DEPLOYMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0026"1/v1/{name=projects/*/locations/*/models/*}:deploy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="UndeployModel",
            full_name="google.cloud.automl.v1.AutoMl.UndeployModel",
            index=14,
            containing_service=None,
            input_type=_UNDEPLOYMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0028"3/v1/{name=projects/*/locations/*/models/*}:undeploy:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ExportModel",
            full_name="google.cloud.automl.v1.AutoMl.ExportModel",
            index=15,
            containing_service=None,
            input_type=_EXPORTMODELREQUEST,
            output_type=google_dot_longrunning_dot_operations__pb2._OPERATION,
            serialized_options=_b(
                '\202\323\344\223\0026"1/v1/{name=projects/*/locations/*/models/*}:export:\001*'
            ),
        ),
        _descriptor.MethodDescriptor(
            name="GetModelEvaluation",
            full_name="google.cloud.automl.v1.AutoMl.GetModelEvaluation",
            index=16,
            containing_service=None,
            input_type=_GETMODELEVALUATIONREQUEST,
            output_type=google_dot_cloud_dot_automl__v1_dot_proto_dot_model__evaluation__pb2._MODELEVALUATION,
            serialized_options=_b(
                "\202\323\344\223\002?\022=/v1/{name=projects/*/locations/*/models/*/modelEvaluations/*}"
            ),
        ),
        _descriptor.MethodDescriptor(
            name="ListModelEvaluations",
            full_name="google.cloud.automl.v1.AutoMl.ListModelEvaluations",
            index=17,
            containing_service=None,
            input_type=_LISTMODELEVALUATIONSREQUEST,
            output_type=_LISTMODELEVALUATIONSRESPONSE,
            serialized_options=_b(
                "\202\323\344\223\002?\022=/v1/{parent=projects/*/locations/*/models/*}/modelEvaluations"
            ),
        ),
    ],
)
_sym_db.RegisterServiceDescriptor(_AUTOML)

DESCRIPTOR.services_by_name["AutoMl"] = _AUTOML

# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/temporal.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/temporal.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1\352\002\036Google::Cloud::AutoML::V1beta1"
    ),
    serialized_pb=_b(
        '\n0google/cloud/automl_v1beta1/proto/temporal.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/api/annotations.proto"w\n\x0bTimeSegment\x12\x34\n\x11start_time_offset\x18\x01 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x32\n\x0f\x65nd_time_offset\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationB\xa5\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1\xea\x02\x1eGoogle::Cloud::AutoML::V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
    ],
)


_TIMESEGMENT = _descriptor.Descriptor(
    name="TimeSegment",
    full_name="google.cloud.automl.v1beta1.TimeSegment",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="start_time_offset",
            full_name="google.cloud.automl.v1beta1.TimeSegment.start_time_offset",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="end_time_offset",
            full_name="google.cloud.automl.v1beta1.TimeSegment.end_time_offset",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=143,
    serialized_end=262,
)

_TIMESEGMENT.fields_by_name[
    "start_time_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_TIMESEGMENT.fields_by_name[
    "end_time_offset"
].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
DESCRIPTOR.message_types_by_name["TimeSegment"] = _TIMESEGMENT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TimeSegment = _reflection.GeneratedProtocolMessageType(
    "TimeSegment",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TIMESEGMENT,
        __module__="google.cloud.automl_v1beta1.proto.temporal_pb2",
        __doc__="""A time period inside of an example that has a time
  dimension (e.g. video).
  
  
  Attributes:
      start_time_offset:
          Start of the time segment (inclusive), represented as the
          duration since the example start.
      end_time_offset:
          End of the time segment (exclusive), represented as the
          duration since the example start.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TimeSegment)
    ),
)
_sym_db.RegisterMessage(TimeSegment)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
